@@ -4,19 +4,20 @@ import copy
 from django import forms
 from django.contrib.admin.models import ADDITION, CHANGE, DELETION, LogEntry
 from django.contrib.contenttypes.models import ContentType
-from django.utils.html import format_html
-from django.utils.safestring import mark_safe
+
+from crudlfap import html
 
 
 class CreateMixin:
     style = 'success'
-    material_icon = 'add'
+    icon = 'add'
     default_template_name = 'crudlfap/create.html'
+    template_name_suffixes = ['create', 'form']
     controller = 'modal'
     action = 'click->modal#open'
     color = 'green'
     log_action_flag = ADDITION
-    menus = ['main', 'model']
+    menus = ['model']
     permission_shortcode = 'add'
 
     def form_valid(self):
@@ -24,10 +25,38 @@ class CreateMixin:
         return super().form_valid()
 
 
-class DeleteMixin:
+class ActionMixin:
+    def has_perm(self):
+        """
+        Call has_perm_object or return True.
+
+        When called without an object, return True if router agrees.
+
+        Otherwise, return the result of has_perm_object(), that you must
+        implement, to return wether permission is accepted for a particular
+        object.
+
+        To override yourself, again go inside an if super().has_perm(): to
+        benefit from this behaviour.
+        """
+        if super().has_perm():
+            if hasattr(self, 'object'):
+                return self.has_perm_object()
+            return True
+
+    def has_perm_object(self):
+        """
+        Override this method: test self.object then return True.
+
+        By default, return True.
+        """
+        return True
+
+
+class DeleteMixin(ActionMixin):
     style = 'danger'
     fa_icon = 'trash'
-    material_icon = 'delete'
+    icon = 'delete'
     success_url_next = True
     color = 'red'
     log_action_flag = DELETION
@@ -49,7 +78,7 @@ class DeleteMixin:
 
 class DetailMixin:
     fa_icon = 'search-plus'
-    material_icon = 'search'
+    icon = 'search'
     default_template_name = 'crudlfap/detail.html'
     color = 'blue'
     menus_display = ['object', 'object_detail']
@@ -81,16 +110,15 @@ class DetailMixin:
             return getattr(self.object, value_getter)()
         value = getattr(self.object, name)
         if hasattr(value, 'get_absolute_url'):
-            return format_html(
-                '<a href="{}">{}</a>',
-                mark_safe(value.get_absolute_url()),
-                value
-            )
+            return html.A(
+                str(value),
+                href=value.get_absolute_url(),
+            ).render()
         return value
 
 
 class HistoryMixin:
-    material_icon = 'history'
+    icon = 'history'
     template_name_suffix = '_history'
     default_template_name = 'crudlfap/history.html'
     controller = None
@@ -106,11 +134,14 @@ class HistoryMixin:
 
 class ListMixin:
     default_template_name = 'crudlfap/list.html'
-    material_icon = 'list'
+    icon = 'list'
     body_class = 'full-width'
     menus = ['main', 'model']
     title_heading = None
 
+    def get_title(self):
+        return self.model._meta.verbose_name_plural.capitalize()
+
     def get_urlpath(self):
         return ''
 
@@ -119,8 +150,9 @@ class ListMixin:
 
 
 class UpdateMixin:
-    material_icon = 'edit'
+    icon = 'edit'
     default_template_name = 'crudlfap/update.html'
+    template_name_suffixes = ['create', 'form']
     controller = 'modal'
     action = 'click->modal#open'
     color = 'orange'
