@@ -3,23 +3,27 @@ import collections
 from django.apps import apps
 from django.urls import path
 
+from .factory import Factory
 from .router import ViewsDescriptor
 
-
 crudlfap = apps.get_app_config('crudlfap')  # pylint: disable=invalid-name
 
 
-class Registry(collections.OrderedDict):
+class Registry(Factory, collections.OrderedDict):
     views = ViewsDescriptor()
 
-    def __getattr__(self, attr):
-        if attr.startswith('get_'):
-            raise AttributeError('{} or {}()'.format(attr[4:], attr))
-
-        if hasattr(self, 'get_' + attr):
-            return getattr(self, 'get_' + attr)()
-
-        raise AttributeError('{} or get_{}()'.format(attr, attr))
+    def get_menu(self, name, request, **kwargs):
+        result = []
+        for view in self.views:
+            menus = getattr(view, 'menus', [])
+            if name in menus and view(request=request).has_perm():
+                result.append(view)
+        for model, router in self.items():
+            menu = router.get_menu(name, request, **kwargs)
+            if not menu:
+                continue
+            result += menu
+        return result
 
     def get_app_menus(self, name, request, **kwargs):
         """Sort Router instances by app name."""
@@ -82,4 +86,4 @@ class Registry(collections.OrderedDict):
         return 'CRUDLFA+'
 
     def get_navbar_color(self):
-        return 'teal darken-3'
+        return ''
