@@ -124,11 +124,11 @@ A settings file to import boilerplate from.
 
 
 import os
+import sys
 from pathlib import Path
 
 from crudlfap.conf import install_optional  # noqa
 
-
 # Build paths inside the project like this: os.path.join(BASE_DIR, ...)
 BASE_DIR = os.path.dirname(os.path.dirname(os.path.dirname(
     os.path.abspath(__file__))))
@@ -142,7 +142,9 @@ SECRET_KEY = os.environ.get('SECRET_KEY', 'notsecret')
 # SECURITY WARNING: don't run with debug turned on in production!
 DEBUG = bool(os.environ.get('DEBUG', False))
 
-if DEBUG and 'ALLOWED_HOSTS' not in os.environ:
+if 'HOST' in os.environ:
+    ALLOWED_HOSTS = [os.environ.get('HOST')]
+elif DEBUG and 'ALLOWED_HOSTS' not in os.environ:
     ALLOWED_HOSTS = ['*']
 else:
     ALLOWED_HOSTS = os.environ.get('ALLOWED_HOSTS', '').split(',')
@@ -157,11 +159,14 @@ CRUDLFAP_VIEWS = [
 
 CRUDLFAP_APPS = [
     'crudlfap',
-    'bootstrap3',
-    'material',
-    'crudlfap_auth',
+    'crudlfap_sites',
     'django_filters',
     'django_tables2',
+    'crudlfap_auth',
+    'ryzom',
+    'py2js',
+    'ryzom_django',
+    'ryzom_django_mdc',
 ]
 
 DJANGO_APPS = [
@@ -170,6 +175,7 @@ DJANGO_APPS = [
     'django.contrib.auth',
     'django.contrib.sessions',
     'django.contrib.messages',
+    'django.contrib.sites',
     'django.contrib.staticfiles',
 ]
 
@@ -177,15 +183,15 @@ INSTALLED_APPS = DJANGO_APPS + CRUDLFAP_APPS
 
 # CRUDLFA+ optional dependencies
 OPTIONAL_APPS = [
-    # {'debug_toolbar': {'after': 'django.contrib.staticfiles'}},
+    {'debug_toolbar': {'after': 'django.contrib.staticfiles'}},
     {'django_extensions': {'before': 'crudlfap'}},
-    {'collectdir': {'before': 'crudlfap'}},
 ]
 
 MIDDLEWARE = [
     'django.middleware.security.SecurityMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
     'django.middleware.common.CommonMiddleware',
+    'ryzom_unpoly.middleware.UnpolyMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
     'django.contrib.auth.middleware.AuthenticationMiddleware',
     'django.contrib.messages.middleware.MessageMiddleware',
@@ -193,92 +199,28 @@ MIDDLEWARE = [
 ]
 
 OPTIONAL_MIDDLEWARE = [
-    # {'debug_toolbar.middleware.DebugToolbarMiddleware': None}
+    {'debug_toolbar.middleware.DebugToolbarMiddleware': None}
 ]
 
 INTERNAL_IPS = ('127.0.0.1',)
 
 ROOT_URLCONF = 'crudlfap_example.urls'
 
-TEMPLATE_CONSTANTS = {
-    "settings": dict(
-        SITE_NAME='CRUDLFA+DEMO',
-        SITE_TITLE='CRUDLFA+ demo !',
-        DEBUG=DEBUG,
-    ),
-}
-
 CRUDLFAP_TEMPLATE_BACKEND = {
-    "BACKEND": "django_jinja.backend.Jinja2",
-    "APP_DIRS": True,
-    "NAME": "crudlfap",
-    "OPTIONS": {
-        "app_dirname": "jinja2",
-        "match_extension": None,
-        "context_processors": [
-            "django.template.context_processors.debug",
-            "django.template.context_processors.request",
-            "django.contrib.auth.context_processors.auth",
-            "django.contrib.messages.context_processors.messages",
-            "django.template.context_processors.i18n",
-        ],
-        "extensions": [
-            "jinja2.ext.do",
-            "jinja2.ext.loopcontrols",
-            "jinja2.ext.with_",
-            "jinja2.ext.i18n",
-            "jinja2.ext.autoescape",
-            "django_jinja.builtins.extensions.CsrfExtension",
-            "django_jinja.builtins.extensions.CacheExtension",
-            "django_jinja.builtins.extensions.TimezoneExtension",
-            "django_jinja.builtins.extensions.UrlsExtension",
-            "django_jinja.builtins.extensions.StaticFilesExtension",
-            "django_jinja.builtins.extensions.DjangoFiltersExtension",
-        ],
-        "constants": TEMPLATE_CONSTANTS,
-        "globals": {
-            "pagination_filter_params": "crudlfap.jinja2.pagination_filter_params",  # noqa
-            "crudlfap_site": "crudlfap.site.site",
-            "getattr": getattr,
-            "str": str,
-            "int": int,
-            "isinstance": isinstance,
-            "type": type,
-            "render_form": "crudlfap.jinja2.render_form",
-            "render_button": "bootstrap3.forms.render_button",
-            "url": "django.urls.reverse",
-        },
-        "newstyle_gettext": True,
-        "bytecode_cache": {
-            "name": "default",
-            "backend": "django_jinja.cache.BytecodeCache",
-            "enabled": False,
-        },
-        "autoescape": True,
-        "auto_reload": DEBUG,
-        "translation_engine": "django.utils.translation",
-    }
+    'BACKEND': 'ryzom_django.template_backend.Ryzom',
+    'NAME': 'ryzom',
 }
 
-try:
-    import webpack_loader  # noqa
-except ImportError:
-    pass
-else:
-    CRUDLFAP_TEMPLATE_BACKEND['OPTIONS']['globals'].setdefault(
-        'render_bundle',
-        'webpack_loader.templatetags.webpack_loader.render_bundle',
-    )
-
 DEFAULT_TEMPLATE_BACKEND = {
-    "BACKEND": "django.template.backends.django.DjangoTemplates",
-    "APP_DIRS": True,
-    "OPTIONS": {
-        "context_processors": [
-            "django.template.context_processors.debug",
-            "django.template.context_processors.request",
-            "django.contrib.auth.context_processors.auth",
-            "django.contrib.messages.context_processors.messages",
+    'BACKEND': 'django.template.backends.django.DjangoTemplates',
+    'DIRS': [],
+    'APP_DIRS': True,
+    'OPTIONS': {
+        'context_processors': [
+            'django.template.context_processors.debug',
+            'django.template.context_processors.request',
+            'django.contrib.auth.context_processors.auth',
+            'django.contrib.messages.context_processors.messages',
         ],
     },
 }
@@ -306,10 +248,28 @@ DATABASES = {
         'NAME': os.getenv('DB_NAME', os.path.join(BASE_DIR, 'db.sqlite3')),
         'HOST': os.getenv('DB_HOST'),
         'USER': os.getenv('DB_USER'),
-        'PASSWORD': os.getenv('DB_PASSWORD'),
+        'PASSWORD': os.getenv('DB_PASS'),
     }
 }
 
+EMAIL_HOST = os.getenv('EMAIL_HOST', None)
+EMAIL_PORT = os.getenv('EMAIL_PORT', None)
+EMAIL_HOST_USER = os.getenv('EMAIL_HOST_USER', None)
+EMAIL_HOST_PASSWORD = os.getenv('EMAIL_HOST_PASSWORD', None)
+EMAIL_USE_TLS = os.getenv('EMAIL_USE_TLS', None)
+EMAIL_USE_SSL = os.getenv('EMAIL_USE_SSL', None)
+DEFAULT_FROM_EMAIL = os.getenv('DEFAULT_FROM_EMAIL', 'noreply@electeez.com')
+
+if EMAIL_HOST:
+    EMAIL_BACKEND = 'django.core.mail.backends.smtp.EmailBackend'
+else:
+    EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'
+
+
+REGISTRATION_OPEN = True     # django-registration
+ACCOUNT_ACTIVATION_DAYS = 7  # django-registration
+LOGIN_REDIRECT_URL = '/'     # django.contrib.auth
+USE_X_FORWARDED_HOST = True  # reverse proxy support
 
 # Password validation
 # https://docs.djangoproject.com/en/1.9/ref/settings/#auth-password-validators
@@ -352,6 +312,8 @@ STATIC_ROOT = os.getenv(
     'STATIC_ROOT',
     Path(os.path.dirname(__file__)) / 'static'
 )
+if 'collectstatic' in sys.argv or not DEBUG:
+    STATICFILES_STORAGE = 'django.contrib.staticfiles.storage.ManifestStaticFilesStorage'  # noqa
 
 UWSGI_SPOOLER_MOUNT = os.getenv('UWSGI_SPOOLER_MOUNT')
 UWSGI_SPOOLER_NAMES = os.getenv('UWSGI_SPOOLER_NAMES', '').split(',')
