@@ -1,8 +1,37 @@
-from crudlfap import crudlfap
+from crudlfap import shortcuts as crudlfap
 
 from .models import Post
 
 
+class AuthBackend:
+    def authenticate(self, *args):
+        return None  # prevent auth from this backend
+
+    def has_perm(self, user_obj, perm, obj=None):
+        view = obj
+
+        if view.model != Post:
+            return False
+
+        user = user_obj
+        code = view.permission_shortcode
+
+        if code in ('list', 'detail'):
+            return True
+        elif code == 'add':
+            return user.is_authenticated
+        elif code == 'change':
+            return view.object.editable(user)
+        elif code == 'delete':
+            if hasattr(view, 'object'):
+                return view.object.editable(user)
+
+            # DeleteObjects relies on get_queryset to secure runtime
+            return user.is_authenticated
+
+        return super().has_perm(user_obj, perm, obj)
+
+
 class PostMixin:
     def get_exclude(self):
         if not self.request.user.is_staff:
@@ -29,7 +58,7 @@ class PostListView(crudlfap.ListView):
 
 class PostRouter(crudlfap.Router):
     fields = '__all__'
-    icon = 'music'
+    icon = 'book'
     model = Post
 
     views = [
@@ -43,30 +72,15 @@ class PostRouter(crudlfap.Router):
         ),
     ]
 
-    def allowed(self, view):
-        """Example getting out of the django permission system."""
-        user = view.request.user
-        perms = view.required_permissions
+    def get_queryset(self, view):
+        qs = self.model.objects.get_queryset()
+        if view.request.user.is_superuser:
+            return qs
+        elif view.permission_shortcode in ('change', 'delete'):
+            return qs.editable(view.request.user)
+        elif view.permission_shortcode in ('list', 'detail'):
+            return qs.readable(view.request.user)
+        return qs.none()
 
-        if perms == ['blog.add_post']:
-            return user.is_authenticated
-        elif perms == ['blog.change_post']:
-            return view.object.editable(user)
-        elif perms == ['blog.delete_post']:
-            if hasattr(view, 'object'):
-                return view.object.editable(user)
-
-            # DeleteObjects relies on get_objects_for_user
-            return user.is_authenticated
-
-        return True
-
-    def get_objects_for_user(self, user, perms):
-        if perms in [['blog.change_post'], ['blog.delete_post']]:
-            return self.model.objects.get_queryset().editable(user)
-        elif perms in [['blog.list_post'], ['blog.detail_post']]:
-            return self.model.objects.get_queryset().readable(user)
-        else:
-            return self.model.objects.get_queryset().none()
 
 PostRouter().register()
