@@ -4,8 +4,11 @@ INSTALLED_APPS += [  # noqa
     # CRUDLFA+ examples
     'crudlfap_example.artist',
     'crudlfap_example.song',
-    'crudlfap_example.nondb',
     'crudlfap_example.blog',
+
+    # CRUDLFA+ extras
+    'django_registration',
+    'crudlfap_registration',
 ]
 
 install_optional(OPTIONAL_APPS, INSTALLED_APPS)  # noqa
